**Example 1: 下线隔离状态的云数据库实例**



Input: 

```
tccli mongodb OfflineIsolatedDBInstance --cli-unfold-argument  \
    --InstanceId cmgo-f555zzzz
```

Output: 
```
{
    "Response": {
        "RequestId": "6EF60BEC-0242-43AF-BB20-270359FB54A7",
        "AsyncRequestId": "28920"
    }
}
```

